sp500: S&P 500 Stock Data

sp500R Documentation

S&P 500 Stock Data

Description

The sp500 data file contains a year's worth of close-of-day data for most of the Standard and Poor's 500 stocks. The data are in reverse chronological order, with the first row corresponding to December 31, 2008.

Usage

data("sp500")

Format

A list containing the following two matrices:

sp500.percent

A 252 by 494 matrix of daily percentage changes. The first column is the DJIA index, the second is the S&P 500 index, and the remaining columns are labeled individual stocks.

sp500.2008

A 253 by 494 matrix of raw close-of-day data. The first column is the DJIA index, the second is the S&P 500 index, and the remaining columns are labeled individual stocks.

Redistributed from version 1.0.1 of the GPL-2-licensed R package scalreg.

References

This database was used in the R package plus.

Examples

data("sp500")
names(sp500)
dim(sp500$sp500.percent)

attach(sp500)
head(sp500.percent[, 1:5])
detach(sp500)

autotune documentation built on Aug. 21, 2026, 5:18 p.m.