| sp500 | R Documentation |
The sp500 data file contains a year's worth of close-of-day data
for most of the Standard and Poor's 500 stocks. The data are in reverse
chronological order, with the first row corresponding to December 31,
2008.
data("sp500")
A list containing the following two matrices:
sp500.percentA 252 by 494 matrix of daily percentage changes. The first column is the DJIA index, the second is the S&P 500 index, and the remaining columns are labeled individual stocks.
sp500.2008A 253 by 494 matrix of raw close-of-day data. The first column is the DJIA index, the second is the S&P 500 index, and the remaining columns are labeled individual stocks.
Redistributed from version 1.0.1 of the GPL-2-licensed R package scalreg.
This database was used in the R package plus.
data("sp500")
names(sp500)
dim(sp500$sp500.percent)
attach(sp500)
head(sp500.percent[, 1:5])
detach(sp500)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.